@@ -4,7 +4,7 @@ from abc import ABC, abstractmethod
 class LearningFunction(ABC):
     def __init(self, ordered_parameters=None, **kwargs):
         self.parameters = kwargs
-        self.ordered_parameters = (ordered_parameters if not None else tuple(kwargs.keys()))
+        self.ordered_parameters = (ordered_parameters if ordered_parameters is not None else tuple(kwargs.keys()))
         if len(self.ordered_parameters) != len(self.parameters):
             raise ValueError("Inconsistent dimensions between order_params tuple and params dictionary.")
 
